OC.L10N.register(
    "theming",
    {
    "The given name is too long" : "Името е прекалено дълго",
    "The given web address is too long" : "Въведеният уеб адрес е твърде дълъг",
    "The given web address is not a valid URL" : "Въведеният уеб адрес не е валиден URL адрес",
    "The given legal notice address is too long" : "Въведеният адрес за юридическо уведомление е твърде дълъг",
    "The given legal notice address is not a valid URL" : "Въведеният адрес за юридическо уведомление не е валиден URL адрес",
    "The given privacy policy address is too long" : "Въведеният адрес на политиката за поверителност е твърде дълъг",
    "The given privacy policy address is not a valid URL" : "Въведеният адрес на политиката за поверителност не е валиден URL адрес",
    "The given slogan is too long" : "Избраният лозунг е твърде дълъг",
    "The given color is invalid" : "Избраният цвят е невалиден",
    "Disable-user-theming should be true or false" : "Опцията Деактивиране - на - тематични - настройки, би трябвало да е вярна или невярна",
    "Saved" : "Запазено",
    "The file was uploaded" : "Файлът е качен",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Размерът на каченият файл надвишава директивата upload_max_filesize в php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Размерът на файла надвишава максималния размер определен от MAX_FILE_SIZE в HTML формата.",
    "The file was only partially uploaded" : "Файлът е качен частично",
    "No file was uploaded" : "Нито един файл не е качен",
    "Missing a temporary folder" : "Липсва временна папка",
    "Could not write file to disk" : " Файлът не можа да бъде записан на диск",
    "A PHP extension stopped the file upload" : "PHP разширение спря качването на файла",
    "No file uploaded" : "Няма качен файл",
    "You are already using a custom theme. Theming app settings might be overwritten by that." : "Вече използвате персонализирана тема. Настройките на приложението за теми могат да бъдат презаписани от това.",
    "Theming" : "Теми",
    "Appearance and accessibility" : "Изглед и достъпност",
    "The PHP module \"imagick\" is not enabled although the theming app is. For favicon generation to work correctly, you need to install and enable this module." : "PHP модулът \"imagick\" не е активиран, въпреки че приложението за теми е активирано. За да работи правилно генерирането на аватари тип favicon, трябва да инсталирате и активирате този модул.",
    "Dark theme with high contrast mode" : "Тъмна тема с режим на висок контраст",
    "Enable dark high contrast mode" : "Активиране на тъмен режим с висок контраст",
    "Similar to the high contrast mode, but with dark colours." : "Подобно на режима с висок контраст, но с тъмни цветове.",
    "Dark theme" : "Tъмна Tема",
    "Enable dark theme" : "Активиране на тъмна тема",
    "A dark theme to ease your eyes by reducing the overall luminosity and brightness." : "Тъмна тема, която да улесни очите ви, като намали общата осветеност и яркост.",
    "System default theme" : "Системна тема по подразбиране",
    "Enable the system default" : "Активиране на системата по подразбиране",
    "Using the default system appearance." : "Използване на изглед на системата по подразбиране.",
    "Dyslexia font" : "Шрифт за дислексия",
    "Enable dyslexia font" : "Активирай шрифт за дислексия",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia." : "OpenDyslexic е безплатен шрифт, предназначен за смекчаване на някои от често срещаните грешки при четенето, причинени от дислексия.",
    "High contrast mode" : "Висок контраст",
    "Enable high contrast mode" : "Активиране на режим с висок контраст",
    "A high contrast mode to ease your navigation. Visual quality will be reduced but clarity will be increased." : "Режим с висок контраст за улесняване на навигацията ви. Визуалното качество ще бъде намалено, но яснотата ще се увеличи.",
    "Light theme" : "Светла тема",
    "Enable the default light theme" : "Активиране на светлата тема по подразбиране",
    "The default light appearance." : "Светъл изглед по подразбиране.",
    "Legal notice" : "Правна информация",
    "Privacy policy" : "Политика за поверителност",
    "Adjust the Nextcloud theme" : "Коригиране на темата на Nextcloud",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "Чрез темите можете бързо и лесно за персонализирате вида на Nextcloud. Промените ще бъдат видими за всички потребители.",
    "Advanced options" : "Допълнителни опции",
    "Install the ImageMagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "Инсталирайте разширението Imagemagick PHP с поддръжка за SVG изображения, за да генерирате автоматично фавикони въз основа на каченото лого и цвят.",
    "Name" : "Име",
    "Web link" : "URL",
    "a safe home for all your data" : "безопасен дом за всички ваши данни",
    "Slogan" : "Лозунг",
    "Color" : "Цвят",
    "Logo" : "Лого",
    "Upload new logo" : "Качване на ново лого",
    "Background and login image" : "Изображение за фон и вход",
    "Upload new background and login image" : "Качване на нов фон и изображение за вход",
    "Legal notice link" : "Връзка за правна информация",
    "Privacy policy link" : "Връзка към политиката за поверителност",
    "Header logo" : "Главно лого",
    "Upload new header logo" : "Качване на ново лого на заглавката",
    "Favicon" : "Фавиконка",
    "Upload new favicon" : "Качване на нов фавикон",
    "User settings" : "Потребителски настройки",
    "Disable user theming" : "Деактивиране на тематичните настройки на потребителите",
    "Although you can select and customize your instance, users can change their background and colors. If you want to enforce your customization, you can toggle this on." : "Въпреки че можете да изберете и персонализирате вашият екземпляр, потребителите могат да променят своя фон и цветове. Ако искате да наложите персонализирането си, можете да включите тази опция.",
    "Background" : "Фон",
    "Customization has been disabled by your administrator" : "Възможността за персонализация е била деактивирана от вашия администратор",
    "Set a custom background" : "Задаване на персонализиран фон",
    "Keyboard shortcuts" : "Бързи клавиши",
    "In some cases keyboard shortcuts can interfere with accessibility tools. In order to allow focusing on your tool correctly you can disable all keyboard shortcuts here. This will also disable all available shortcuts in apps." : "В някои случаи бързите клавишни комбинации могат да пречат на инструментите за достъпност. За да се позволи правилно фокусиране върху инструмента, можете да деактивирате всички клавишни комбинации тук. Това ще деактивира и всички налични преки пътища в приложенията.",
    "Disable all keyboard shortcuts" : "Деактивиране на всички бързи клавишни комбинации",
    "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 on AA level, with the high contrast theme even on AAA level." : "Универсалният достъп е много важен за нас. Следваме уеб стандартите и проверяваме, за да направим всичко използваемо и без мишка, и помощен софтуер, като екранни четци. Ние се стремим да бъдем съобразени с {guidelines}Насоки за достъпност на уеб съдържанието {linkend} 2.1 на ниво АА, с темата за висок контраст дори на ниво AAA.",
    "If you find any issues, do not hesitate to report them on {issuetracker}our issue tracker{linkend}. And if you want to get involved, come join {designteam}our design team{linkend}!" : "Ако откриете някакви проблеми, не се колебайте да ги съобщите на {issueetracker}, нашият тракер на проблеми {linkend}. И ако искате да се включите, елате да се присъедините {designteam} към нашия дизайнерски екип {linkend}!",
    "Move up" : "Преместване нагоре",
    "Move down" : "Преместване  надолу",
    "Custom background" : "Персонализиран фон",
    "Default background" : "Фон по подразбиране",
    "Change color" : "Промяна на цвета",
    "No background" : "Без фон",
    "Select a background from your files" : "Избор на фон от вашите файлове",
    "Theme selection is enforced" : "Изборът на тема е приложен",
    "Reset to default" : "Настройки по подразбиране",
    "Upload" : "Качване",
    "Remove background image" : "Премахни фоновото изображение",
    "Failed to clean up the old administration theming images folder" : "Неуспешно почистване на папка със стари изображения на администраторски теми",
    "Failed to clean up the old administration image folder" : "Неуспешно почистване на старата папка с изображения на администратора",
    "Select a custom color" : "Избор на персонализиран цвят"
},
"nplurals=2; plural=(n != 1);");
